import React from "react";
import { UserManagerSettings, User } from "oidc-client";
export interface AuthProviderProps extends UserManagerSettings {
    /**
     * The child nodes your Provider has wrapped
     */
    children?: React.ReactNode;
    /**
     * On sign out hook. Can be a async function.
     * @param user User
     */
    onSignIn?: (user: User | null) => Promise<void> | void;
    /**
     * On sign out hook. Can be a async function.
     */
    onSignOut?: () => Promise<void> | void;
    /**
     * By default, if the page url has code/state params, the SDK will call automatically the userManager.signinCallback.
     * In some cases the code might be for something else (another OAuth SDK perhaps). In these
     * instances you can instruct the client to ignore them eg
     *
     * ```jsx
     * <AuthProvider
     *   skipSigninCallback={window.location.pathname === '/stripe-oauth-callback'}
     * >
     * ```
     */
    skipSigninCallback?: boolean;
}
/**
 * Provides the AuthContext to its child components.
 */
export declare const AuthProvider: (props: AuthProviderProps) => JSX.Element;
